pitchtools.calculate_melodic_diatonic_interval
==============================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_diatonic_interval.calculate_melodic_diatonic_interval
   :noindex:
